@@ -2,96 +2,75 @@
 use strict;
 use warnings;
 
-use vars qw( $VERSION $debug );
-$VERSION = "5.04";
-
 use English qw( -no_match_vars );
 use Getopt::Long;
 use Pod::Usage;
 
-use lib "lib";
-
-use Mail::Toaster          5; my $toaster = Mail::Toaster->new;
-use Mail::Toaster::FreeBSD 5; my $freebsd = Mail::Toaster::FreeBSD->new;
-use Mail::Toaster::Perl    5; my $perl    = Mail::Toaster::Perl->new;
-use Mail::Toaster::Qmail   5; my $qmail   = Mail::Toaster::Qmail->new;
-use Mail::Toaster::Utility 5; my $util    = Mail::Toaster::Utility->new;
-use Mail::Toaster::Apache  5; my $apache  = Mail::Toaster::Apache->new;
+use lib 'lib';
+use Mail::Toaster          5.25; 
+use Mail::Toaster::Apache  5.25; 
+use Mail::Toaster::FreeBSD 5.25; 
+use Mail::Toaster::Qmail   5.25; 
+use Mail::Toaster::Setup   5.25; 
+use Mail::Toaster::Utility 5.25; 
 
 $OUTPUT_AUTOFLUSH++;
 
 my %command_line_options = (
-#	'action=s'  => \my $action,
 	'secti=s'   => \my $section,
-	'debug'     => \$debug,
-	'verbose'   => \$debug,
+	'verbose'   => \my $debug,
 );
 GetOptions (%command_line_options);
 
 $debug = 0 unless defined $debug;
+
+my $toaster = Mail::Toaster->new( debug => $debug );
+my $apache  = Mail::Toaster::Apache->new( 'log' =>$toaster );
+my $freebsd = Mail::Toaster::FreeBSD->new( 'log'  => $toaster );
+my $qmail   = Mail::Toaster::Qmail->new( 'log'  => $toaster );
+my $util = $toaster->get_util;
+my $conf = $toaster->get_config;
+
 print "verbose mode enabled\n\n" if $debug;
 
-unless ( $section ) { 
+if ( ! $section ) { 
     pod2usage( { -verbose=>0, }); 
     die "You must choose a section!\n"; 
 };
 
 # these sections do not require root privs to run
-my $root_agnostic = {
-    help   => 1,  docs => 1, test2  => 1,
-};
+my $root_agnostic = { help => 1, docs => 1, test2 => 1, };
 
 # everything else requires root
 if ( $UID != 0 && !$root_agnostic->{$section} ) { 
 	die "Thou shalt have root to proceed!\n"; 
 };
 
-# don't check for perl version when running these subs
-my $perl_agnostic = {
-    ports   => 1,   sources => 1,   perl    => 1,
-    config  => 1,   help    => 1,
-    jailadd => 1,   jaildelete=>1,  jailstart=>1,
+if ( $debug ) {
+    $conf->{'toaster_debug'} = 1;
+    $toaster->{debug} = 1;
+}
+else {
+    $toaster->{debug} = 0;
 };
 
-if ( ! $perl_agnostic->{$section} ) {
-    $perl->check(debug=>$debug);
-};
-
-# the config file values override whatever the values that are set in this script
-# and sprinkled liberally throughout the code. This gives the user the ability
-# freedom to change things as they wish but still have  reasonable defaults as
-# a starting point. 
-my $conf = $util->parse_config( 
-    file  => "toaster-watcher.conf", 
-    debug => $debug,
-);
-
-$conf->{'toaster_debug'} = 1 if $debug;
-
-use Mail::Toaster::Setup 5; 
-my $setup = Mail::Toaster::Setup->new(conf=>$conf);
+my $setup = Mail::Toaster::Setup->new('log'=>$toaster, conf=>$conf);
 
   $section eq "pre"        ? $setup->dependencies      ()
 : $section eq "cpan"       ? $setup->cpan              ()
-: $section eq "perl"       ? $perl->check              (conf=>$conf, debug=>$debug)
 : $section eq "docs"       ? $setup->docs              ()
 : $section eq "help"       ? pod2usage                 ( {-verbose=>1 } )
 : $section eq "config"     ? $setup->config            ()
 
 : $section eq "ssl"        ? $setup->openssl_conf       ()
 
-#  FreeBSD specific
-: $section eq "sources"    ? $freebsd->source_update  (conf=>$conf, debug=>$debug)
-: $section eq "jailadd"    ? $freebsd->jail_create    (debug=>$debug)
-: $section eq "jaildelete" ? $freebsd->jail_delete    (debug=>$debug)
-: $section eq "jailstart"  ? $freebsd->jail_start     (debug=>$debug)
-
 #  Updates the ports tree on FreeBSD and Darwin
 : $section eq "ports"      ? $setup->ports            ( )
 
 #  Standard daemons & utilities
 : $section eq "mysql"      ? $setup->mysql            ()
 : $section eq "phpmyadmin" ? $setup->phpmyadmin       ()
+: $section eq "lighttpd"   ? $setup->lighttpd         ()
 : $section eq "apache"     ? $setup->apache           ()
 : $section eq "apache1"    ? $setup->apache   ( ver=>1,)
 : $section eq "apache2"    ? $setup->apache   ( ver=>2,)
@@ -130,7 +109,6 @@ my $setup = Mail::Toaster::Setup->new(conf=>$conf);
 : $section eq "razor"       ? $setup->razor            ( )
 : $section eq "maildrop"    ? $setup->maildrop         ( )
 : $section eq "clamav"      ? $setup->clamav           ( )
-: $section eq "qmailscanner"? $setup->qmail_scanner    ( )
 : $section eq "simscan"     ? $setup->simscan          ( )
 : $section eq "simconf"     ? $setup->simscan_conf     ( )
 : $section eq "simtest"     ? $setup->simscan_test     ( )
@@ -142,14 +120,14 @@ my $setup = Mail::Toaster::Setup->new(conf=>$conf);
 : $section eq "qss"         ? $setup->qs_stats         ( )
 : $section eq "socklog"     ? $setup->socklog          ( )
 : $section eq "isoqlog"     ? $setup->isoqlog          ( )
-: $section eq "rrdutil"     ? $setup->rrdutil          ( )
 : $section eq "supervise"   ? $setup->supervise        ( )
+: $section eq "munin"       ? $setup->munin            ( )
 
 # test targets
 : $section eq "test"        ? $setup->test             ( )
 : $section eq "filtertest"  ? $setup->filtering_test   ( )
 : $section eq "authtest"    ? $setup->test_auth        ( )
-: $section eq "proctest"    ? $toaster->test_processes (debug=>$debug)
+: $section eq "proctest"    ? $toaster->check_processes (debug=>$debug)
 : $section eq "imap"        ? $setup->imap_test_auth   ( )
 : $section eq "pop3"        ? $setup->pop3_test_auth   ( )
 : $section eq "smtp"        ? $setup->smtp_test_auth   ( )
@@ -160,7 +138,7 @@ my $setup = Mail::Toaster::Setup->new(conf=>$conf);
 : $section eq "mattbundle"  ? $setup->mattbundle       ( )
 : $section eq "logmonster"  ? $setup->logmonster       ( )
 : $section eq "mrm"         ? $setup->mrm              ( )
-: $section eq "toaster"     ? $util->mailtoaster    (debug=>$debug)
+: $section eq "toaster"     ? $setup->mailtoaster      ( )
 : $section eq "nictool"     ? $setup->nictool          ( )
 : $section eq "webmail"     ? $setup->webmail          ( )
 : $section eq "all"         ? all()
@@ -169,13 +147,14 @@ my $setup = Mail::Toaster::Setup->new(conf=>$conf);
 sub all {
 	$setup->config        ( );
 
-        # re-initialize $conf with new settings. 
-        $conf = $util->parse_config( 
-            file  => "toaster-watcher.conf", 
-            debug => $debug,
-        );
-        $conf->{'toaster_debug'} = 1 if $debug;
-        $setup = Mail::Toaster::Setup->new(conf=>$conf);
+    # re-initialize $conf with new settings. 
+    $conf = $toaster->parse_config( 
+        file  => "toaster-watcher.conf", 
+        debug => $debug,
+    );
+    $toaster->{'debug'} = 1 if $debug;
+    $conf->{'toaster_debug'} = 1 if $debug;
+    $setup = Mail::Toaster::Setup->new('log'=>$toaster, conf => $conf);
 
 	$setup->dependencies  ( );
 	$setup->openssl_conf  ( );
@@ -199,7 +178,6 @@ sub all {
 	$setup->filtering     ( );
 	$setup->maillogs      ( );
 	$setup->supervise     ( );
-	$setup->rrdutil       ( );
 	$setup->test          ( );
 }
 
@@ -314,7 +292,6 @@ A complete set of instructions for building a mail toaster are on the toaster in
             qss - installs qmailscanner stats
         socklog - installs socklog
         isoqlog - installs and configured isoqlog
-        rrdutil - installs rrdutil
       supervise - creates the directories to be used by svscan
 
            test - runs a complete test suite against your server
@@ -379,9 +356,6 @@ The following are all man/perldoc pages:
   Mail::Toaster::FreeBSD
   Mail::Toaster::Logs
   Mail::Toaster::Mysql
-  Mail::Toaster::Passwd
-  Mail::Toaster::Perl
-  Mail::Toaster::Provision
   Mail::Toaster::Qmail
   Mail::Toaster::Setup
   Mail::Toaster::Utility
@@ -394,7 +368,7 @@ The following are all man/perldoc pages:
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004-2008, The Network People, Inc. All rights reserved.
+Copyright (c) 2004-2010, The Network People, Inc. All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
